@@ -135,7 +135,79 @@ sub _text_table {
    return $rv;
 }
 
-
 1;
 
 __END__
+
+=head1 NAME
+
+Text::Template::Simple::Caller - Caller stack tracer for Text::Template::Simple
+
+=head1 SYNOPSIS
+
+   use strict;
+   use Text::Template::Simple::Caller;
+   x();
+   sub x {  y() }
+   sub y {  z() }
+   sub z { print Text::Template::Simple::Caller->stack }
+
+=head1 DESCRIPTION
+
+Caller stack tracer for Text::Template::Simple. This module is not used
+directly inside templates. You must use the global template function
+insted. See L<Text::Template::Simple::Dummy> for usage from the templates.
+
+=head1 METHODS
+
+=head2 stack
+
+Class method. Accepts parameters as a single hashref:
+
+   my $dump = Text::Template::Simple::Caller->stack(\%opts);
+
+=head3 frame
+
+Integer. Defines how many call frames to go back. Default is zero (full list).
+
+=head3 type
+
+Defines the dump type. Available options are:
+
+=over 4
+
+=item string
+
+A simple text dump.
+
+=item html_comment
+
+Same as string, but the output wrapped with HTML comment codes:
+
+   <!-- [DUMP] -->
+
+=item html_table
+
+Returns the dump as a HTML table.
+
+=item text_table
+
+Uses the optional module C<Text::Table> to format the dump.
+
+=back
+
+=head1 AUTHOR
+
+Burak GE<252>rsoy, E<lt>burakE<64>cpan.orgE<gt>
+
+=head1 COPYRIGHT
+
+Copyright 2004-2007 Burak GE<252>rsoy. All rights reserved.
+
+=head1 LICENSE
+
+This library is free software; you can redistribute it and/or modify 
+it under the same terms as Perl itself, either Perl version 5.8.8 or, 
+at your option, any later version of Perl 5 you may have available.
+
+=cut
